==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/association/impl/ClassAsAssociatedOneSideSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.association.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.association.ClassAsAssociatedOneSide;
import io.ciera.tool.sql.ooaofooa.association.ClassAsAssociatedOneSideSet;
import io.ciera.tool.sql.ooaofooa.association.LinkedAssociationSet;
import io.ciera.tool.sql.ooaofooa.association.ReferredToClassInAssocSet;
import io.ciera.tool.sql.ooaofooa.association.impl.LinkedAssociationSetImpl;
import io.ciera.tool.sql.ooaofooa.association.impl.ReferredToClassInAssocSetImpl;

import java.util.Arrays;
import java.util.List;


public class ClassAsAssociatedOneSideSetImpl extends InstanceSet<ClassAsAssociatedOneSideSet,ClassAsAssociatedOneSide> implements ClassAsAssociatedOneSideSet {

    // attributes
    @Override
    public void setRel_ID( UniqueId ref_Rel_ID ) throws XtumlException {
        for ( ClassAsAssociatedOneSide classasassociatedoneside : this ) classasassociatedoneside.setRel_ID( ref_Rel_ID );
    }
    @Override
    public void setOIR_ID( UniqueId ref_OIR_ID ) throws XtumlException {
        for ( ClassAsAssociatedOneSide classasassociatedoneside : this ) classasassociatedoneside.setOIR_ID( ref_OIR_ID );
    }
    @Override
    public void setObj_ID( UniqueId ref_Obj_ID ) throws XtumlException {
        for ( ClassAsAssociatedOneSide classasassociatedoneside : this ) classasassociatedoneside.setObj_ID( ref_Obj_ID );
    }
    @Override
    public void setMult( int m_Mult ) throws XtumlException {
        for ( ClassAsAssociatedOneSide classasassociatedoneside : this ) classasassociatedoneside.setMult( m_Mult );
    }
    @Override
    public void setTxt_Phrs( String m_Txt_Phrs ) throws XtumlException {
        for ( ClassAsAssociatedOneSide classasassociatedoneside : this ) classasassociatedoneside.setTxt_Phrs( m_Txt_Phrs );
    }
    @Override
    public void setCond( int m_Cond ) throws XtumlException {
        for ( ClassAsAssociatedOneSide classasassociatedoneside : this ) classasassociatedoneside.setCond( m_Cond );
    }


    // selections
    @Override
    public ReferredToClassInAssocSet R204_is_a_ReferredToClassInAssoc() throws XtumlException {
        ReferredToClassInAssocSet referredtoclassinassocset = new ReferredToClassInAssocSetImpl();
        for ( ClassAsAssociatedOneSide classasassociatedoneside : this ) referredtoclassinassocset.add( classasassociatedoneside.R204_is_a_ReferredToClassInAssoc() );
        return referredtoclassinassocset;
    }
    @Override
    public LinkedAssociationSet R209_is_related_to_other_side_via_LinkedAssociation() throws XtumlException {
        LinkedAssociationSet linkedassociationset = new LinkedAssociationSetImpl();
        for ( ClassAsAssociatedOneSide classasassociatedoneside : this ) linkedassociationset.add( classasassociatedoneside.R209_is_related_to_other_side_via_LinkedAssociation() );
        return linkedassociationset;
    }


    @Override
    public ClassAsAssociatedOneSide nullElement() {
        return ClassAsAssociatedOneSideImpl.EMPTY_CLASSASASSOCIATEDONESIDE;
    }

    @Override
    public ClassAsAssociatedOneSideSet emptySet() {
      return new ClassAsAssociatedOneSideSetImpl();
    }

    @Override
    public ClassAsAssociatedOneSideSet value() {
        return this;
    }

    @Override
    public List<ClassAsAssociatedOneSide> elements() {
        return Arrays.asList(toArray(new ClassAsAssociatedOneSide[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/association/impl/ClassAsAssociatedOneSideSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.association.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.association.ClassAsAssociatedOneSide;
import io.ciera.tool.sql.ooaofooa.association.ClassAsAssociatedOneSideSet;
import io.ciera.tool.sql.ooaofooa.association.LinkedAssociationSet;
import io.ciera.tool.sql.ooaofooa.association.ReferredToClassInAssocSet;
import io.ciera.tool.sql.ooaofooa.association.impl.LinkedAssociationSetImpl;
import io.ciera.tool.sql.ooaofooa.association.impl.ReferredToClassInAssocSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class ClassAsAssociatedOneSideSetImpl extends InstanceSet<ClassAsAssociatedOneSideSet,ClassAsAssociatedOneSide> implements ClassAsAssociatedOneSideSet {

    public ClassAsAssociatedOneSideSetImpl() {
    }

    public ClassAsAssociatedOneSideSetImpl(Comparator<? super ClassAsAssociatedOneSide> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setOIR_ID( UniqueId ref_OIR_ID ) throws XtumlException {
        for ( ClassAsAssociatedOneSide classasassociatedoneside : this ) classasassociatedoneside.setOIR_ID( ref_OIR_ID );
    }
    @Override
    public void setObj_ID( UniqueId ref_Obj_ID ) throws XtumlException {
        for ( ClassAsAssociatedOneSide classasassociatedoneside : this ) classasassociatedoneside.setObj_ID( ref_Obj_ID );
    }
    @Override
    public void setRel_ID( UniqueId ref_Rel_ID ) throws XtumlException {
        for ( ClassAsAssociatedOneSide classasassociatedoneside : this ) classasassociatedoneside.setRel_ID( ref_Rel_ID );
    }
    @Override
    public void setTxt_Phrs( String m_Txt_Phrs ) throws XtumlException {
        for ( ClassAsAssociatedOneSide classasassociatedoneside : this ) classasassociatedoneside.setTxt_Phrs( m_Txt_Phrs );
    }
    @Override
    public void setCond( int m_Cond ) throws XtumlException {
        for ( ClassAsAssociatedOneSide classasassociatedoneside : this ) classasassociatedoneside.setCond( m_Cond );
    }
    @Override
    public void setMult( int m_Mult ) throws XtumlException {
        for ( ClassAsAssociatedOneSide classasassociatedoneside : this ) classasassociatedoneside.setMult( m_Mult );
    }


    // selections
    @Override
    public ReferredToClassInAssocSet R204_is_a_ReferredToClassInAssoc() throws XtumlException {
        ReferredToClassInAssocSet referredtoclassinassocset = new ReferredToClassInAssocSetImpl();
        for ( ClassAsAssociatedOneSide classasassociatedoneside : this ) referredtoclassinassocset.add( classasassociatedoneside.R204_is_a_ReferredToClassInAssoc() );
        return referredtoclassinassocset;
    }
    @Override
    public LinkedAssociationSet R209_is_related_to_other_side_via_LinkedAssociation() throws XtumlException {
        LinkedAssociationSet linkedassociationset = new LinkedAssociationSetImpl();
        for ( ClassAsAssociatedOneSide classasassociatedoneside : this ) linkedassociationset.add( classasassociatedoneside.R209_is_related_to_other_side_via_LinkedAssociation() );
        return linkedassociationset;
    }


    @Override
    public ClassAsAssociatedOneSide nullElement() {
        return ClassAsAssociatedOneSideImpl.EMPTY_CLASSASASSOCIATEDONESIDE;
    }

    @Override
    public ClassAsAssociatedOneSideSet emptySet() {
      return new ClassAsAssociatedOneSideSetImpl();
    }

    @Override
    public ClassAsAssociatedOneSideSet emptySet(Comparator<? super ClassAsAssociatedOneSide> comp) {
      return new ClassAsAssociatedOneSideSetImpl(comp);
    }

    @Override
    public ClassAsAssociatedOneSideSet value() {
        return this;
    }

    @Override
    public List<ClassAsAssociatedOneSide> elements() {
        return Arrays.asList(toArray(new ClassAsAssociatedOneSide[0]));
    }

}
